@@ -33,26 +33,6 @@ if (STOMP_DEBUG) {
 }
 
 
-// Implement Array.indexOf (needed in IE 7 or lower).
-// NB: This was borrowed from Mozilla.
-// See http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:indexOf
-if (!Array.prototype.indexOf) {
-    Array.prototype.indexOf = function(elt /*, from*/) {
-        var len = this.length;
-        var from = Number(arguments[1]) || 0;
-        from = (from < 0) ? Math.ceil(from) : Math.floor(from);
-        if (from < 0)
-            from += len;
-        
-        for (; from < len; from++) {
-            if (from in this && this[from] === elt)
-                return from;
-        }
-        return -1;
-    };
-}
-
-
 // NB: This is loosly based on twisted.protocols.basic.LineReceiver
 //     See http://twistedmatrix.com/documents/8.1.0/api/twisted.protocols.basic.LineReceiver.html
 // XXX this assumes the lines are UTF-8 encoded.
